/**
 * List repository for an orgnization.
 * @function listOrgRepo
 * @param {string} name - Name of orgnization.
 * @param {function} callback - Callback when done.
 */

"use strict";

var request = require('request'),
    util = require('util');

/** @lends listOrgRepo */
function listOrgRepo(name, callback) {
    request.get({
        url: util.format("https://api.github.com/orgs/%s/repos", name),
        headers: {
            'User-Agent': "apeman CLI"
        }
    }, function (err, res, body) {
        if (err) {
            callback(err);
        } else {
            var success = res.statusCode == 200;
            if (success) {
                var data = JSON.parse(body).map(function(data){
                    return {
                        name: data.name,
                        full_name: data.full_name,
                        private: data.private,
                        description: data.description,
                        url: data.url,
                        fork: data.fork
                    };
                });
                callback(null, data);
            } else {
                callback(new Error('Request failed with status: ' + res.statusCode));
            }
        }
    });
}

module.exports = listOrgRepo;
